API reference
=============

.. currentmodule:: papylio

Main classes
============

.. autosummary::
    :toctree: _generated/

    papylio.Experiment
    papylio.File
    papylio.Movie

Lower-level function
====================
.. autosummary::
    :toctree: _generated/

    papylio.analysis.dwell_time_analysis